package com.mysql.jdbc;

import com.mysql.jdbc.profiler.ProfileEventSink;
import com.mysql.jdbc.profiler.ProfilerEvent;
import java.io.InputStream;
import java.io.Reader;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.sql.Date;
import java.sql.SQLException;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/UpdatableResultSet.class */
public class UpdatableResultSet extends ResultSetImpl {
    protected static final byte[] STREAM_DATA_MARKER = "** STREAM DATA **".getBytes();
    protected SingleByteCharsetConverter charConverter;
    private String charEncoding;
    private byte[][] defaultColumnValue;
    private PreparedStatement deleter;
    private String deleteSQL;
    private boolean initializedCharConverter;
    protected PreparedStatement inserter;
    private String insertSQL;
    private boolean isUpdatable;
    private String notUpdatableReason;
    private List primaryKeyIndicies;
    private String qualifiedAndQuotedTableName;
    private String quotedIdChar;
    private PreparedStatement refresher;
    private String refreshSQL;
    private ResultSetRow savedCurrentRow;
    private String tableOnlyName;
    protected PreparedStatement updater;
    private String updateSQL;
    private boolean populateInserterWithDefaultValues;

    /* JADX INFO: Access modifiers changed from: protected */
    public UpdatableResultSet(String catalog, Field[] fields, RowData tuples, ConnectionImpl conn, StatementImpl creatorStmt) throws SQLException {
        super(catalog, fields, tuples, conn, creatorStmt);
        this.deleter = null;
        this.deleteSQL = null;
        this.initializedCharConverter = false;
        this.inserter = null;
        this.insertSQL = null;
        this.isUpdatable = false;
        this.notUpdatableReason = null;
        this.primaryKeyIndicies = null;
        this.quotedIdChar = null;
        this.refreshSQL = null;
        this.updater = null;
        this.updateSQL = null;
        this.populateInserterWithDefaultValues = false;
        checkUpdatability();
        this.populateInserterWithDefaultValues = this.connection.getPopulateInsertRowWithDefaultValues();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean absolute(int row) throws SQLException {
        return super.absolute(row);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void afterLast() throws SQLException {
        super.afterLast();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void beforeFirst() throws SQLException {
        super.beforeFirst();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void cancelRowUpdates() throws SQLException {
        checkClosed();
        if (this.doingUpdates) {
            this.doingUpdates = false;
            this.updater.clearParameters();
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.mysql.jdbc.ResultSetImpl
    public void checkRowPos() throws SQLException {
        checkClosed();
        if (!this.onInsertRow) {
            super.checkRowPos();
        }
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:66:0x01e1
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    protected void checkUpdatability() throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 705
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.UpdatableResultSet.checkUpdatability():void");
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void deleteRow() throws SQLException {
        checkClosed();
        if (!this.isUpdatable) {
            throw new NotUpdatable(this.notUpdatableReason);
        }
        if (this.onInsertRow) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.1"));
        }
        if (this.rowData.size() == 0) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.2"));
        }
        if (isBeforeFirst()) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.3"));
        }
        if (isAfterLast()) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.4"));
        }
        if (this.deleter == null) {
            if (this.deleteSQL == null) {
                generateStatements();
            }
            this.deleter = this.connection.clientPrepareStatement(this.deleteSQL);
        }
        this.deleter.clearParameters();
        String characterEncoding = null;
        if (this.connection.getUseUnicode()) {
            characterEncoding = this.connection.getEncoding();
        }
        try {
            int numKeys = this.primaryKeyIndicies.size();
            if (numKeys == 1) {
                int index = ((Integer) this.primaryKeyIndicies.get(0)).intValue();
                String currentVal = characterEncoding == null ? new String(this.thisRow.getColumnValue(index)) : new String(this.thisRow.getColumnValue(index), characterEncoding);
                this.deleter.setString(1, currentVal);
            } else {
                for (int i = 0; i < numKeys; i++) {
                    int index2 = ((Integer) this.primaryKeyIndicies.get(i)).intValue();
                    String currentVal2 = characterEncoding == null ? new String(this.thisRow.getColumnValue(index2)) : new String(this.thisRow.getColumnValue(index2), characterEncoding);
                    this.deleter.setString(i + 1, currentVal2);
                }
            }
            this.deleter.executeUpdate();
            this.rowData.removeRow(this.rowData.getCurrentRowNumber());
        } catch (UnsupportedEncodingException e) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.39", new Object[]{this.charEncoding}), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    /*  JADX ERROR: NullPointerException in pass: RegionMakerVisitor
        java.lang.NullPointerException: Cannot invoke "java.util.List.isEmpty()" because "s" is null
        	at jadx.core.utils.BlockUtils.getNextBlock(BlockUtils.java:411)
        	at jadx.core.dex.visitors.regions.RegionMaker.traverse(RegionMaker.java:172)
        	at jadx.core.dex.visitors.regions.RegionMaker.makeRegion(RegionMaker.java:91)
        	at jadx.core.dex.visitors.regions.RegionMaker.processIf(RegionMaker.java:735)
        	at jadx.core.dex.visitors.regions.RegionMaker.traverse(RegionMaker.java:152)
        	at jadx.core.dex.visitors.regions.RegionMaker.makeRegion(RegionMaker.java:91)
        	at jadx.core.dex.visitors.regions.RegionMaker.processExcHandler(RegionMaker.java:1110)
        	at jadx.core.dex.visitors.regions.RegionMaker.processTryCatchBlocks(RegionMaker.java:1046)
        	at jadx.core.dex.visitors.regions.RegionMakerVisitor.visit(RegionMakerVisitor.java:55)
        */
    /* JADX WARN: Type inference failed for: r1v5, types: [byte[], byte[][]] */
    private synchronized void extractDefaultValues() throws java.sql.SQLException {
        /*
            r6 = this;
            r0 = r6
            com.mysql.jdbc.ConnectionImpl r0 = r0.connection
            java.sql.DatabaseMetaData r0 = r0.getMetaData()
            r7 = r0
            r0 = 0
            r8 = r0
            r0 = r7
            r1 = r6
            java.lang.String r1 = r1.catalog     // Catch: java.lang.Throwable -> Lb6
            r2 = 0
            r3 = r6
            java.lang.String r3 = r3.tableOnlyName     // Catch: java.lang.Throwable -> Lb6
            java.lang.String r4 = "%"
            java.sql.ResultSet r0 = r0.getColumns(r1, r2, r3, r4)     // Catch: java.lang.Throwable -> Lb6
            r8 = r0
            java.util.HashMap r0 = new java.util.HashMap     // Catch: java.lang.Throwable -> Lb6
            r1 = r0
            r2 = r6
            com.mysql.jdbc.Field[] r2 = r2.fields     // Catch: java.lang.Throwable -> Lb6
            int r2 = r2.length     // Catch: java.lang.Throwable -> Lb6
            r1.<init>(r2)     // Catch: java.lang.Throwable -> Lb6
            r9 = r0
        L29:
            r0 = r8
            boolean r0 = r0.next()     // Catch: java.lang.Throwable -> Lb6
            if (r0 == 0) goto L52
            r0 = r8
            java.lang.String r1 = "COLUMN_NAME"
            java.lang.String r0 = r0.getString(r1)     // Catch: java.lang.Throwable -> Lb6
            r10 = r0
            r0 = r8
            java.lang.String r1 = "COLUMN_DEF"
            byte[] r0 = r0.getBytes(r1)     // Catch: java.lang.Throwable -> Lb6
            r11 = r0
            r0 = r9
            r1 = r10
            r2 = r11
            java.lang.Object r0 = r0.put(r1, r2)     // Catch: java.lang.Throwable -> Lb6
            goto L29
        L52:
            r0 = r6
            com.mysql.jdbc.Field[] r0 = r0.fields     // Catch: java.lang.Throwable -> Lb6
            int r0 = r0.length     // Catch: java.lang.Throwable -> Lb6
            r10 = r0
            r0 = r6
            r1 = r10
            byte[] r1 = new byte[r1]     // Catch: java.lang.Throwable -> Lb6
            r0.defaultColumnValue = r1     // Catch: java.lang.Throwable -> Lb6
            r0 = 0
            r11 = r0
        L65:
            r0 = r11
            r1 = r10
            if (r0 >= r1) goto Lb0
            r0 = r6
            com.mysql.jdbc.Field[] r0 = r0.fields     // Catch: java.lang.Throwable -> Lb6
            r1 = r11
            r0 = r0[r1]     // Catch: java.lang.Throwable -> Lb6
            java.lang.String r0 = r0.getOriginalName()     // Catch: java.lang.Throwable -> Lb6
            r12 = r0
            r0 = r12
            if (r0 == 0) goto L85
            r0 = r12
            int r0 = r0.length()     // Catch: java.lang.Throwable -> Lb6
            if (r0 != 0) goto L91
        L85:
            r0 = r6
            com.mysql.jdbc.Field[] r0 = r0.fields     // Catch: java.lang.Throwable -> Lb6
            r1 = r11
            r0 = r0[r1]     // Catch: java.lang.Throwable -> Lb6
            java.lang.String r0 = r0.getName()     // Catch: java.lang.Throwable -> Lb6
            r12 = r0
        L91:
            r0 = r12
            if (r0 == 0) goto Laa
            r0 = r9
            r1 = r12
            java.lang.Object r0 = r0.get(r1)     // Catch: java.lang.Throwable -> Lb6
            byte[] r0 = (byte[]) r0     // Catch: java.lang.Throwable -> Lb6
            r13 = r0
            r0 = r6
            byte[][] r0 = r0.defaultColumnValue     // Catch: java.lang.Throwable -> Lb6
            r1 = r11
            r2 = r13
            r0[r1] = r2     // Catch: java.lang.Throwable -> Lb6
        Laa:
            int r11 = r11 + 1
            goto L65
        Lb0:
            r0 = jsr -> Lbe
        Lb3:
            goto Lce
        Lb6:
            r14 = move-exception
            r0 = jsr -> Lbe
        Lbb:
            r1 = r14
            throw r1
        Lbe:
            r15 = r0
            r0 = r8
            if (r0 == 0) goto Lcc
            r0 = r8
            r0.close()
            r0 = 0
            r8 = r0
        Lcc:
            ret r15
        Lce:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.UpdatableResultSet.extractDefaultValues():void");
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean first() throws SQLException {
        return super.first();
    }

    protected synchronized void generateStatements() throws SQLException {
        String columnName;
        if (!this.isUpdatable) {
            this.doingUpdates = false;
            this.onInsertRow = false;
            throw new NotUpdatable(this.notUpdatableReason);
        }
        String quotedId = getQuotedIdChar();
        if (this.fields[0].getOriginalTableName() != null) {
            StringBuffer tableNameBuffer = new StringBuffer();
            String databaseName = this.fields[0].getDatabaseName();
            if (databaseName != null && databaseName.length() > 0) {
                tableNameBuffer.append(quotedId);
                tableNameBuffer.append(databaseName);
                tableNameBuffer.append(quotedId);
                tableNameBuffer.append('.');
            }
            this.tableOnlyName = this.fields[0].getOriginalTableName();
            tableNameBuffer.append(quotedId);
            tableNameBuffer.append(this.tableOnlyName);
            tableNameBuffer.append(quotedId);
            this.qualifiedAndQuotedTableName = tableNameBuffer.toString();
        } else {
            StringBuffer tableNameBuffer2 = new StringBuffer();
            this.tableOnlyName = this.fields[0].getTableName();
            tableNameBuffer2.append(quotedId);
            tableNameBuffer2.append(this.tableOnlyName);
            tableNameBuffer2.append(quotedId);
            this.qualifiedAndQuotedTableName = tableNameBuffer2.toString();
        }
        this.primaryKeyIndicies = new ArrayList();
        StringBuffer fieldValues = new StringBuffer();
        StringBuffer keyValues = new StringBuffer();
        StringBuffer columnNames = new StringBuffer();
        StringBuffer insertPlaceHolders = new StringBuffer();
        boolean firstTime = true;
        boolean keysFirstTime = true;
        String equalsStr = this.connection.versionMeetsMinimum(3, 23, 0) ? "<=>" : "=";
        for (int i = 0; i < this.fields.length; i++) {
            String originalColumnName = this.fields[i].getOriginalName();
            if (this.connection.getIO().hasLongColumnInfo() && originalColumnName != null && originalColumnName.length() > 0) {
                columnName = originalColumnName;
            } else {
                columnName = this.fields[i].getName();
            }
            if (this.fields[i].isPrimaryKey()) {
                this.primaryKeyIndicies.add(Constants.integerValueOf(i));
                if (!keysFirstTime) {
                    keyValues.append(" AND ");
                } else {
                    keysFirstTime = false;
                }
                keyValues.append(quotedId);
                keyValues.append(columnName);
                keyValues.append(quotedId);
                keyValues.append(equalsStr);
                keyValues.append("?");
            }
            if (firstTime) {
                firstTime = false;
                fieldValues.append("SET ");
            } else {
                fieldValues.append(",");
                columnNames.append(",");
                insertPlaceHolders.append(",");
            }
            insertPlaceHolders.append("?");
            columnNames.append(quotedId);
            columnNames.append(columnName);
            columnNames.append(quotedId);
            fieldValues.append(quotedId);
            fieldValues.append(columnName);
            fieldValues.append(quotedId);
            fieldValues.append("=?");
        }
        this.updateSQL = new StringBuffer().append("UPDATE ").append(this.qualifiedAndQuotedTableName).append(" ").append(fieldValues.toString()).append(" WHERE ").append(keyValues.toString()).toString();
        this.insertSQL = new StringBuffer().append("INSERT INTO ").append(this.qualifiedAndQuotedTableName).append(" (").append(columnNames.toString()).append(") VALUES (").append(insertPlaceHolders.toString()).append(")").toString();
        this.refreshSQL = new StringBuffer().append("SELECT ").append(columnNames.toString()).append(" FROM ").append(this.qualifiedAndQuotedTableName).append(" WHERE ").append(keyValues.toString()).toString();
        this.deleteSQL = new StringBuffer().append("DELETE FROM ").append(this.qualifiedAndQuotedTableName).append(" WHERE ").append(keyValues.toString()).toString();
    }

    private synchronized SingleByteCharsetConverter getCharConverter() throws SQLException {
        if (!this.initializedCharConverter) {
            this.initializedCharConverter = true;
            if (this.connection.getUseUnicode()) {
                this.charEncoding = this.connection.getEncoding();
                this.charConverter = this.connection.getCharsetConverter(this.charEncoding);
            }
        }
        return this.charConverter;
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public int getConcurrency() throws SQLException {
        return this.isUpdatable ? MysqlErrorNumbers.ER_DB_DROP_EXISTS : MysqlErrorNumbers.ER_DB_CREATE_EXISTS;
    }

    private synchronized String getQuotedIdChar() throws SQLException {
        if (this.quotedIdChar == null) {
            boolean useQuotedIdentifiers = this.connection.supportsQuotedIdentifiers();
            if (useQuotedIdentifiers) {
                java.sql.DatabaseMetaData dbmd = this.connection.getMetaData();
                this.quotedIdChar = dbmd.getIdentifierQuoteString();
            } else {
                this.quotedIdChar = "";
            }
        }
        return this.quotedIdChar;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v13, types: [byte[], byte[][]] */
    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void insertRow() throws SQLException {
        checkClosed();
        if (!this.onInsertRow) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.7"));
        }
        this.inserter.executeUpdate();
        long autoIncrementId = this.inserter.getLastInsertID();
        int numFields = this.fields.length;
        ?? r0 = new byte[numFields];
        for (int i = 0; i < numFields; i++) {
            if (this.inserter.isNull(i)) {
                r0[i] = 0;
            } else {
                r0[i] = this.inserter.getBytesRepresentation(i);
            }
            if (this.fields[i].isAutoIncrement() && autoIncrementId > 0) {
                r0[i] = String.valueOf(autoIncrementId).getBytes();
                this.inserter.setBytesNoEscapeNoQuotes(i + 1, r0[i]);
            }
        }
        ResultSetRow resultSetRow = new ByteArrayRow(r0);
        refreshRow(this.inserter, resultSetRow);
        this.rowData.addRow(resultSetRow);
        resetInserter();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean isAfterLast() throws SQLException {
        return super.isAfterLast();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean isBeforeFirst() throws SQLException {
        return super.isBeforeFirst();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean isFirst() throws SQLException {
        return super.isFirst();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean isLast() throws SQLException {
        return super.isLast();
    }

    boolean isUpdatable() {
        return this.isUpdatable;
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean last() throws SQLException {
        return super.last();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void moveToCurrentRow() throws SQLException {
        checkClosed();
        if (!this.isUpdatable) {
            throw new NotUpdatable(this.notUpdatableReason);
        }
        if (this.onInsertRow) {
            this.onInsertRow = false;
            this.thisRow = this.savedCurrentRow;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v24 */
    /* JADX WARN: Type inference failed for: r0v40 */
    /* JADX WARN: Type inference failed for: r8v0, types: [byte[][]] */
    /* JADX WARN: Type inference failed for: r8v1 */
    /* JADX WARN: Type inference failed for: r8v2 */
    /* JADX WARN: Type inference failed for: r8v3 */
    /* JADX WARN: Type inference failed for: r8v6 */
    /* JADX WARN: Type inference failed for: r8v7 */
    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void moveToInsertRow() throws SQLException {
        checkClosed();
        if (!this.isUpdatable) {
            throw new NotUpdatable(this.notUpdatableReason);
        }
        if (this.inserter == null) {
            if (this.insertSQL == null) {
                generateStatements();
            }
            this.inserter = this.connection.clientPrepareStatement(this.insertSQL);
            if (this.populateInserterWithDefaultValues) {
                extractDefaultValues();
            }
            resetInserter();
        } else {
            resetInserter();
        }
        int length = this.fields.length;
        this.onInsertRow = true;
        this.doingUpdates = false;
        this.savedCurrentRow = this.thisRow;
        ?? r8 = new byte[length];
        this.thisRow = new ByteArrayRow(r8);
        int i = 0;
        ?? r82 = r8;
        while (i < length) {
            if (!this.populateInserterWithDefaultValues) {
                this.inserter.setBytesNoEscapeNoQuotes(i + 1, "DEFAULT".getBytes());
                r82 = (byte[][]) null;
            } else if (this.defaultColumnValue[i] != null) {
                switch (this.fields[i].getMysqlType()) {
                    case 7:
                    case 10:
                    case 11:
                    case 12:
                    case 14:
                        if (this.defaultColumnValue[i].length > 7 && this.defaultColumnValue[i][0] == 67 && this.defaultColumnValue[i][1] == 85 && this.defaultColumnValue[i][2] == 82 && this.defaultColumnValue[i][3] == 82 && this.defaultColumnValue[i][4] == 69 && this.defaultColumnValue[i][5] == 78 && this.defaultColumnValue[i][6] == 84 && this.defaultColumnValue[i][7] == 95) {
                            this.inserter.setBytesNoEscapeNoQuotes(i + 1, this.defaultColumnValue[i]);
                            break;
                        }
                        break;
                }
                this.inserter.setBytes(i + 1, this.defaultColumnValue[i], false, false);
                byte[] bArr = new byte[this.defaultColumnValue[i].length];
                System.arraycopy(this.defaultColumnValue[i], 0, bArr, 0, bArr.length);
                (r82 == true ? 1 : 0)[i] = bArr;
            } else {
                this.inserter.setNull(i + 1, 0);
                (r82 == true ? 1 : 0)[i] = 0;
            }
            i++;
            r82 = r82;
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean next() throws SQLException {
        return super.next();
    }

    @Override // com.mysql.jdbc.ResultSetImpl
    public synchronized boolean prev() throws SQLException {
        return super.prev();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean previous() throws SQLException {
        return super.previous();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, com.mysql.jdbc.ResultSetInternalMethods
    public void realClose(boolean calledExplicitly) throws SQLException {
        if (this.isClosed) {
            return;
        }
        SQLException sqlEx = null;
        if (this.useUsageAdvisor && this.deleter == null && this.inserter == null && this.refresher == null && this.updater == null) {
            this.eventSink = ProfileEventSink.getInstance(this.connection);
            String message = Messages.getString("UpdatableResultSet.34");
            this.eventSink.consumeEvent(new ProfilerEvent((byte) 0, "", this.owningStatement == null ? "N/A" : this.owningStatement.currentCatalog, this.connectionId, this.owningStatement == null ? -1 : this.owningStatement.getId(), this.resultId, System.currentTimeMillis(), 0L, Constants.MILLIS_I18N, (String) null, this.pointOfOrigin, message));
        }
        try {
            if (this.deleter != null) {
                this.deleter.close();
            }
        } catch (SQLException ex) {
            sqlEx = ex;
        }
        try {
            if (this.inserter != null) {
                this.inserter.close();
            }
        } catch (SQLException ex2) {
            sqlEx = ex2;
        }
        try {
            if (this.refresher != null) {
                this.refresher.close();
            }
        } catch (SQLException ex3) {
            sqlEx = ex3;
        }
        try {
            if (this.updater != null) {
                this.updater.close();
            }
        } catch (SQLException ex4) {
            sqlEx = ex4;
        }
        super.realClose(calledExplicitly);
        if (sqlEx != null) {
            throw sqlEx;
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void refreshRow() throws SQLException {
        checkClosed();
        if (!this.isUpdatable) {
            throw new NotUpdatable();
        }
        if (this.onInsertRow) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.8"));
        }
        if (this.rowData.size() == 0) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.9"));
        }
        if (isBeforeFirst()) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.10"));
        }
        if (isAfterLast()) {
            throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.11"));
        }
        refreshRow(this.updater, this.thisRow);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:32:0x01b5
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:88)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:52)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:44)
        */
    private synchronized void refreshRow(com.mysql.jdbc.PreparedStatement r7, com.mysql.jdbc.ResultSetRow r8) throws java.sql.SQLException {
        /*
            Method dump skipped, instructions count: 442
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.mysql.jdbc.UpdatableResultSet.refreshRow(com.mysql.jdbc.PreparedStatement, com.mysql.jdbc.ResultSetRow):void");
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean relative(int rows) throws SQLException {
        return super.relative(rows);
    }

    private void resetInserter() throws SQLException {
        this.inserter.clearParameters();
        for (int i = 0; i < this.fields.length; i++) {
            this.inserter.setNull(i + 1, 0);
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean rowDeleted() throws SQLException {
        throw new NotImplemented();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean rowInserted() throws SQLException {
        throw new NotImplemented();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized boolean rowUpdated() throws SQLException {
        throw new NotImplemented();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.mysql.jdbc.ResultSetImpl
    public void setResultSetConcurrency(int concurrencyFlag) {
        super.setResultSetConcurrency(concurrencyFlag);
    }

    private byte[] stripBinaryPrefix(byte[] dataFrom) {
        return StringUtils.stripEnclosure(dataFrom, "_binary'", "'");
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public synchronized void syncUpdate() throws SQLException {
        if (this.updater == null) {
            if (this.updateSQL == null) {
                generateStatements();
            }
            this.updater = this.connection.clientPrepareStatement(this.updateSQL);
        }
        int numFields = this.fields.length;
        this.updater.clearParameters();
        for (int i = 0; i < numFields; i++) {
            if (this.thisRow.getColumnValue(i) != null) {
                this.updater.setBytes(i + 1, this.thisRow.getColumnValue(i), this.fields[i].isBinary(), false);
            } else {
                this.updater.setNull(i + 1, 0);
            }
        }
        int numKeys = this.primaryKeyIndicies.size();
        if (numKeys == 1) {
            int index = ((Integer) this.primaryKeyIndicies.get(0)).intValue();
            byte[] keyData = this.thisRow.getColumnValue(index);
            this.updater.setBytes(numFields + 1, keyData, false, false);
            return;
        }
        for (int i2 = 0; i2 < numKeys; i2++) {
            byte[] currentVal = this.thisRow.getColumnValue(((Integer) this.primaryKeyIndicies.get(i2)).intValue());
            if (currentVal != null) {
                this.updater.setBytes(numFields + i2 + 1, currentVal, false, false);
            } else {
                this.updater.setNull(numFields + i2 + 1, 0);
            }
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateAsciiStream(int columnIndex, InputStream x, int length) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setAsciiStream(columnIndex, x, length);
            return;
        }
        this.inserter.setAsciiStream(columnIndex, x, length);
        this.thisRow.setColumnValue(columnIndex - 1, STREAM_DATA_MARKER);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateAsciiStream(String columnName, InputStream x, int length) throws SQLException {
        updateAsciiStream(findColumn(columnName), x, length);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBigDecimal(int columnIndex, BigDecimal x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setBigDecimal(columnIndex, x);
            return;
        }
        this.inserter.setBigDecimal(columnIndex, x);
        if (x == null) {
            this.thisRow.setColumnValue(columnIndex - 1, null);
        } else {
            this.thisRow.setColumnValue(columnIndex - 1, x.toString().getBytes());
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBigDecimal(String columnName, BigDecimal x) throws SQLException {
        updateBigDecimal(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBinaryStream(int columnIndex, InputStream x, int length) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setBinaryStream(columnIndex, x, length);
            return;
        }
        this.inserter.setBinaryStream(columnIndex, x, length);
        if (x == null) {
            this.thisRow.setColumnValue(columnIndex - 1, null);
        } else {
            this.thisRow.setColumnValue(columnIndex - 1, STREAM_DATA_MARKER);
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBinaryStream(String columnName, InputStream x, int length) throws SQLException {
        updateBinaryStream(findColumn(columnName), x, length);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBlob(int columnIndex, java.sql.Blob blob) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setBlob(columnIndex, blob);
            return;
        }
        this.inserter.setBlob(columnIndex, blob);
        if (blob == null) {
            this.thisRow.setColumnValue(columnIndex - 1, null);
        } else {
            this.thisRow.setColumnValue(columnIndex - 1, STREAM_DATA_MARKER);
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBlob(String columnName, java.sql.Blob blob) throws SQLException {
        updateBlob(findColumn(columnName), blob);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBoolean(int columnIndex, boolean x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setBoolean(columnIndex, x);
            return;
        }
        this.inserter.setBoolean(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBoolean(String columnName, boolean x) throws SQLException {
        updateBoolean(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateByte(int columnIndex, byte x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setByte(columnIndex, x);
            return;
        }
        this.inserter.setByte(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateByte(String columnName, byte x) throws SQLException {
        updateByte(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBytes(int columnIndex, byte[] x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setBytes(columnIndex, x);
            return;
        }
        this.inserter.setBytes(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateBytes(String columnName, byte[] x) throws SQLException {
        updateBytes(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateCharacterStream(int columnIndex, Reader x, int length) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setCharacterStream(columnIndex, x, length);
            return;
        }
        this.inserter.setCharacterStream(columnIndex, x, length);
        if (x == null) {
            this.thisRow.setColumnValue(columnIndex - 1, null);
        } else {
            this.thisRow.setColumnValue(columnIndex - 1, STREAM_DATA_MARKER);
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateCharacterStream(String columnName, Reader reader, int length) throws SQLException {
        updateCharacterStream(findColumn(columnName), reader, length);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public void updateClob(int columnIndex, java.sql.Clob clob) throws SQLException {
        if (clob == null) {
            updateNull(columnIndex);
        } else {
            updateCharacterStream(columnIndex, clob.getCharacterStream(), (int) clob.length());
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateDate(int columnIndex, Date x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setDate(columnIndex, x);
            return;
        }
        this.inserter.setDate(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateDate(String columnName, Date x) throws SQLException {
        updateDate(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateDouble(int columnIndex, double x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setDouble(columnIndex, x);
            return;
        }
        this.inserter.setDouble(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateDouble(String columnName, double x) throws SQLException {
        updateDouble(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateFloat(int columnIndex, float x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setFloat(columnIndex, x);
            return;
        }
        this.inserter.setFloat(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateFloat(String columnName, float x) throws SQLException {
        updateFloat(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateInt(int columnIndex, int x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setInt(columnIndex, x);
            return;
        }
        this.inserter.setInt(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateInt(String columnName, int x) throws SQLException {
        updateInt(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateLong(int columnIndex, long x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setLong(columnIndex, x);
            return;
        }
        this.inserter.setLong(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateLong(String columnName, long x) throws SQLException {
        updateLong(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateNull(int columnIndex) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setNull(columnIndex, 0);
            return;
        }
        this.inserter.setNull(columnIndex, 0);
        this.thisRow.setColumnValue(columnIndex - 1, null);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateNull(String columnName) throws SQLException {
        updateNull(findColumn(columnName));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateObject(int columnIndex, Object x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setObject(columnIndex, x);
            return;
        }
        this.inserter.setObject(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateObject(int columnIndex, Object x, int scale) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setObject(columnIndex, x);
            return;
        }
        this.inserter.setObject(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateObject(String columnName, Object x) throws SQLException {
        updateObject(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateObject(String columnName, Object x, int scale) throws SQLException {
        updateObject(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateRow() throws SQLException {
        if (!this.isUpdatable) {
            throw new NotUpdatable(this.notUpdatableReason);
        }
        if (this.doingUpdates) {
            this.updater.executeUpdate();
            refreshRow();
            this.doingUpdates = false;
        }
        syncUpdate();
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateShort(int columnIndex, short x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setShort(columnIndex, x);
            return;
        }
        this.inserter.setShort(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateShort(String columnName, short x) throws SQLException {
        updateShort(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateString(int columnIndex, String x) throws SQLException {
        checkClosed();
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setString(columnIndex, x);
            return;
        }
        this.inserter.setString(columnIndex, x);
        if (x == null) {
            this.thisRow.setColumnValue(columnIndex - 1, null);
        } else if (getCharConverter() != null) {
            this.thisRow.setColumnValue(columnIndex - 1, StringUtils.getBytes(x, this.charConverter, this.charEncoding, this.connection.getServerCharacterEncoding(), this.connection.parserKnowsUnicode()));
        } else {
            this.thisRow.setColumnValue(columnIndex - 1, x.getBytes());
        }
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateString(String columnName, String x) throws SQLException {
        updateString(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateTime(int columnIndex, Time x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setTime(columnIndex, x);
            return;
        }
        this.inserter.setTime(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateTime(String columnName, Time x) throws SQLException {
        updateTime(findColumn(columnName), x);
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateTimestamp(int columnIndex, Timestamp x) throws SQLException {
        if (!this.onInsertRow) {
            if (!this.doingUpdates) {
                this.doingUpdates = true;
                syncUpdate();
            }
            this.updater.setTimestamp(columnIndex, x);
            return;
        }
        this.inserter.setTimestamp(columnIndex, x);
        this.thisRow.setColumnValue(columnIndex - 1, this.inserter.getBytesRepresentation(columnIndex - 1));
    }

    @Override // com.mysql.jdbc.ResultSetImpl, java.sql.ResultSet
    public synchronized void updateTimestamp(String columnName, Timestamp x) throws SQLException {
        updateTimestamp(findColumn(columnName), x);
    }
}
